@@ -395,6 +395,14 @@ class GenericEditorPresenter(object):
         # used by assign_completions_handler
         self._prev_text = {}
 
+        # _problem_widgets was introduced in 0.9.7 in order to cache the
+        # widgets that had problems attached to them so that the
+        # widget background could be reverted to normal after the
+        # presenter is closed...this because an issue when we starting
+        # using cached gtk+...this should be fixed in 1.0
+        self._problem_widgets = []
+
+
 
     # whether the presenter should be commited or not
     def dirty(self):
@@ -442,26 +450,34 @@ class GenericEditorPresenter(object):
         self.problems.add(problem_id)
         if isinstance(problem_widgets, (tuple, list)):
             for w in problem_widgets:
+                self._problem_widgets.append(w)
                 w.modify_bg(gtk.STATE_NORMAL, self.problem_color)
                 w.modify_base(gtk.STATE_NORMAL, self.problem_color)
                 w.queue_draw()
         elif problem_widgets is not None:
+            self._problem_widgets.append(problem_widgets)
             problem_widgets.modify_bg(gtk.STATE_NORMAL, self.problem_color)
             problem_widgets.modify_base(gtk.STATE_NORMAL, self.problem_color)
             problem_widgets.queue_draw()
 
 
-    def init_enum_combo(self, widget_name, field):
+    def init_enum_combo(self, widget_name, field, none_str=None):
         """
         initialize a gtk.ComboBox widget with name widget_name from enum values
         in self.model.field
+
+        WARNING: replacing None with the empty string is really
+        dangerous since it might mean that a value is stored in the
+        column that is not in the Enum...you should ensure that the
+        changed handler on the combo converts the none_str back to
+        None when you store the value in the model
         """
         combo = self.view.widgets[widget_name]
         mapper = object_mapper(self.model)
         values = sorted(mapper.c[field].type.values)
-        if None in values:
+        if None in values and none_str is not None:
             values.remove(None)
-            values.insert(0, '')
+            values.insert(0, none_str)
         utils.setup_text_combobox(combo, values)
 
 
@@ -647,6 +663,9 @@ class GenericEditorPresenter(object):
 
 
     def cleanup(self):
+        for widget in self._problem_widgets:
+            widget.modify_bg(gtk.STATE_NORMAL, None)
+            widget.modify_base(gtk.STATE_NORMAL, None)
         self.view.cleanup()
 
 
@@ -697,7 +716,13 @@ class GenericModelViewPresenterEditor(object):
         '''
         Commit the changes.
         '''
-        self.session.commit()
+        objs = list(self.session)
+        try:
+            self.session.commit()
+        except:
+            self.session.rollback()
+            self.session.add_all(objs)
+            raise
         return True
 
 
