@@ -144,6 +144,8 @@ def remove_callback(value):
         msg = _('Could not delete.\n\n%s') % utils.xml_safe_utf8(unicode(e))
         utils.message_details_dialog(msg, traceback.format_exc(),
                                      type=gtk.MESSAGE_ERROR)
+    finally:
+        session.close()
     return True
 
 
@@ -444,7 +446,9 @@ class Accession(db.Base):
         if self.source is not None:
             obj = self.source
             obj.accession = None
-            utils.delete_or_expunge(obj)
+            # we don't need to delete the old source since it will be
+            # orphaned and should get automatically deleted
+            #utils.delete_or_expunge(obj)
             self.source_type = None
         if source is None:
             self.source_type = None
@@ -504,6 +508,7 @@ class AccessionEditorView(GenericEditorView):
                                    parent=parent)
         self.dialog = self.widgets.accession_dialog
         self.dialog.set_transient_for(parent)
+        self.set_accept_buttons_sensitive(False)
         self.attach_completion('acc_species_entry',
                                cell_data_func=self.species_cell_data_func,
                                match_func=self.species_match_func)
@@ -539,6 +544,14 @@ class AccessionEditorView(GenericEditorView):
             self.widgets[expander].set_expanded(expanded)
 
 
+    def set_accept_buttons_sensitive(self, sensitive):
+        '''
+        set the sensitivity of all the accept/ok buttons for the editor dialog
+        '''
+        self.widgets.acc_ok_button.set_sensitive(sensitive)
+        self.widgets.acc_ok_and_add_button.set_sensitive(sensitive)
+        self.widgets.acc_next_button.set_sensitive(sensitive)
+
     def start(self):
         return self.widgets.accession_dialog.run()
 
@@ -716,7 +729,7 @@ class CollectionPresenter(GenericEditorPresenter):
 
         latitude = self.model.latitude
         if latitude is not None:
-            dms_string ='%s %s\302\260%s"%s\'' % latitude_to_dms(latitude)
+            dms_string ='%s %s\302\260%s\'%s"' % latitude_to_dms(latitude)
             self.view.widgets.lat_dms_label.set_text(dms_string)
             if latitude < 0:
                 self.view.widgets.south_radio.set_active(True)
@@ -724,7 +737,7 @@ class CollectionPresenter(GenericEditorPresenter):
                 self.view.widgets.north_radio.set_active(True)
         longitude = self.model.longitude
         if longitude is not None:
-            dms_string ='%s %s\302\260%s"%s\'' % longitude_to_dms(longitude)
+            dms_string ='%s %s\302\260%s\'%s"' % longitude_to_dms(longitude)
             self.view.widgets.lon_dms_label.set_text(dms_string)
             if longitude < 0:
                 self.view.widgets.west_radio.set_active(True)
@@ -889,7 +902,7 @@ class CollectionPresenter(GenericEditorPresenter):
                 direction = self._get_lat_direction()
                 latitude = CollectionPresenter._parse_lat_lon(direction, text)
                 #u"\N{DEGREE SIGN}"
-                dms_string ='%s %s\302\260%s"%s\'' % latitude_to_dms(latitude)
+                dms_string ='%s %s\302\260%s\'%s"' % latitude_to_dms(latitude)
         except Exception:
 #            debug(traceback.format_exc())
             bg_color = gtk.gdk.color_parse("red")
@@ -931,7 +944,7 @@ class CollectionPresenter(GenericEditorPresenter):
                 east_radio.handler_unblock(self.east_toggle_signal_id)
                 direction = self._get_lon_direction()
                 longitude = CollectionPresenter._parse_lat_lon(direction, text)
-                dms_string ='%s %s\302\260%s"%s\'' % longitude_to_dms(longitude)
+                dms_string='%s %s\302\260%s\'%s"' % longitude_to_dms(longitude)
         except Exception:
 #            debug(traceback.format_exc())
             bg_color = gtk.gdk.color_parse("red")
@@ -1190,9 +1203,10 @@ class AccessionEditorPresenter(GenericEditorPresenter):
         # set current page so we don't open the last one that was open
         self.view.widgets.acc_notebook.set_current_page(0)
 
-        self.init_enum_combo('acc_prov_combo', 'prov_type')
-        self.init_enum_combo('acc_wild_prov_combo', 'wild_prov_status')
-        self.init_enum_combo('acc_id_qual_combo', 'id_qual')
+        self.init_enum_combo('acc_prov_combo', 'prov_type', none_str='')
+        self.init_enum_combo('acc_wild_prov_combo', 'wild_prov_status',
+                             none_str='')
+        self.init_enum_combo('acc_id_qual_combo', 'id_qual', none_str='')
 
         # init id_qual_rank
         utils.setup_text_combobox(self.view.widgets.acc_id_qual_rank_combo)
@@ -1218,11 +1232,14 @@ class AccessionEditorPresenter(GenericEditorPresenter):
             except Exception:
                 pass
             from utils import ilike
-            return query.filter(and_(Species.genus_id == Genus.id,
-                                     or_(ilike(Genus.genus, '%s%%' % text),
-                                         ilike(Genus.genus, '%s%%' % genus),
-                                         ilike(Genus.hybrid,
-                                               utils.utf8(text)))))
+            if text.startswith('x'):
+                or_cond = or_(ilike(Genus.genus, '%s%%' % text),
+                              ilike(Genus.genus, '%s%%' % genus),
+                              ilike(Genus.hybrid, utils.utf8(text[0])))
+            else:
+                or_cond = or_(ilike(Genus.genus, '%s%%' % text),
+                              ilike(Genus.genus, '%s%%' % genus))
+            return query.filter(and_(Species.genus_id == Genus.id, or_cond))
 
         def on_select(value):
             self.set_model_attr('species', value)
@@ -1433,7 +1450,7 @@ class AccessionEditorPresenter(GenericEditorPresenter):
             sensitive = False
         elif not self.model.code or not self.model.species:
             sensitive = False
-        self.set_accept_buttons_sensitive(sensitive)
+        self.view.set_accept_buttons_sensitive(sensitive)
 
 
     def on_source_type_combo_changed(self, combo, data=None):
@@ -1508,16 +1525,6 @@ class AccessionEditorPresenter(GenericEditorPresenter):
                                        self.session)
 
 
-
-    def set_accept_buttons_sensitive(self, sensitive):
-        '''
-        set the sensitivity of all the accept/ok buttons for the editor dialog
-        '''
-        self.view.widgets.acc_ok_button.set_sensitive(sensitive)
-        self.view.widgets.acc_ok_and_add_button.set_sensitive(sensitive)
-        self.view.widgets.acc_next_button.set_sensitive(sensitive)
-
-
     def init_source_tab(self):
         '''
         initialized the source expander contents
@@ -1534,7 +1541,10 @@ class AccessionEditorPresenter(GenericEditorPresenter):
 
 
     def on_combo_changed(self, combo, field):
-        self.set_model_attr(field, utils.utf8(combo.get_active_text()))
+        value = utils.utf8(combo.get_active_text())
+        if value == u'':
+            value = None
+        self.set_model_attr(field, value)
 
 
     def refresh_view(self):
@@ -1608,7 +1618,6 @@ class AccessionEditor(GenericModelViewPresenterEditor):
                 msg = _('Error committing changes.\n\n%s') % \
                       utils.xml_safe_utf8(unicode(e.orig))
                 utils.message_details_dialog(msg, str(e), gtk.MESSAGE_ERROR)
-                self.session.rollback()
                 return False
             except Exception, e:
                 msg = _('Unknown error when committing changes. See the '\
@@ -1617,7 +1626,6 @@ class AccessionEditor(GenericModelViewPresenterEditor):
                 debug(traceback.format_exc())
                 utils.message_details_dialog(msg, traceback.format_exc(),
                                              gtk.MESSAGE_ERROR)
-                self.session.rollback()
                 return False
         elif self.presenter.dirty() and utils.yes_no_dialog(not_ok_msg) \
                  or not self.presenter.dirty():
@@ -1629,6 +1637,7 @@ class AccessionEditor(GenericModelViewPresenterEditor):
         # respond to responses
         more_committed = None
         if response == self.RESPONSE_NEXT:
+            self.presenter.cleanup()
             e = AccessionEditor(parent=self.parent)
             more_committed = e.start()
         elif response == self.RESPONSE_OK_AND_ADD:
@@ -1780,7 +1789,10 @@ class GeneralAccessionExpander(InfoExpander):
         # TODO: could this be sped up, does it matter?
         nplants = session.query(Plant).filter_by(accession_id=row.id).count()
         self.set_widget_value('nplants_data', nplants)
-        self.set_widget_value('prov_data', row.prov_type, False)
+        prov = ''
+        if row.prov_type:
+            prov = row.prov_type
+        self.set_widget_value('prov_data', prov, False)
 
 
 class NotesExpander(InfoExpander):
@@ -1827,21 +1839,24 @@ class SourceExpander(InfoExpander):
 
         if collection.latitude:
             dir, deg, min, sec = latitude_to_dms(collection.latitude)
-            lat_str = '%.2f (%s %s\302\260%s"%.2f\') %s' % \
+            lat_str = '%.2f (%s %s\302\260%s\'%.2f") %s' % \
                 (collection.latitude, dir, deg, min, sec, geo_accy)
             self.set_widget_value('lat_data', lat_str)
 
         if collection.longitude:
             dir, deg, min, sec = longitude_to_dms(collection.longitude)
-            long_str = '%.2f (%s %s\302\260%s"%.2f\') %s' % \
+            long_str = '%.2f (%s %s\302\260%s\'%.2f") %s' % \
                 (collection.longitude, dir, deg, min, sec, geo_accy)
             self.set_widget_value('lon_data', long_str)
 
-        if collection.elevation_accy:
-            elevation = '%sm (+/- %sm)' % (collection.elevation,
-                                           collection.elevation_accy)
-            self.set_widget_value('elev_data', elevation)
-
+        if collection.elevation:
+            if collection.elevation_accy:
+                elevation = '%sm (+/- %sm)' % (collection.elevation,
+                                               collection.elevation_accy)
+                self.set_widget_value('elev_data', elevation)
+            else:
+                elevation = '%sm' % (collection.elevation)
+                self.set_widget_value('elev_data', elevation)
 
         self.set_widget_value('coll_data', collection.collector)
         self.set_widget_value('date_data', collection.date)
