@@ -76,6 +76,8 @@ def remove_callback(plant):
 
         utils.message_details_dialog(msg, traceback.format_exc(),
                                      type=gtk.MESSAGE_ERROR)
+    finally:
+        session.close()
     return True
 
 
@@ -276,6 +278,8 @@ class PlantEditorView(GenericEditorView):
                                    parent=parent)
         self.dialog = self.widgets.plant_dialog
         self.dialog.set_transient_for(parent)
+        self.widgets.plant_ok_button.set_sensitive(False)
+        self.widgets.plant_next_button.set_sensitive(False)
         self.connect_dialog_close(self.dialog)
         def acc_cell_data_func(column, renderer, model, iter, data=None):
             v = model[iter][0]
@@ -343,8 +347,8 @@ class PlantEditorPresenter(GenericEditorPresenter):
         self.__dirty = False
 
         # initialize widgets
-        self.init_enum_combo('plant_acc_status_combo', 'acc_status')
-        self.init_enum_combo('plant_acc_type_combo', 'acc_type')
+        self.init_enum_combo('plant_acc_status_combo', 'acc_status',none_str='')
+        self.init_enum_combo('plant_acc_type_combo', 'acc_type', none_str='')
 
 #        self.init_history_box()
 
@@ -520,7 +524,6 @@ class PlantEditor(GenericModelViewPresenterEditor):
                 exc = traceback.format_exc()
                 msg = _('Error committing changes.\n\n%s') % e.orig
                 utils.message_details_dialog(msg, str(e), gtk.MESSAGE_ERROR)
-                self.session.rollback()
                 return False
             except Exception, e:
                 msg = _('Unknown error when committing changes. See the '\
@@ -529,7 +532,6 @@ class PlantEditor(GenericModelViewPresenterEditor):
                 debug(traceback.format_exc())
                 utils.message_details_dialog(msg, traceback.format_exc(),
                                              gtk.MESSAGE_ERROR)
-                self.session.rollback()
                 return False
         elif self.presenter.dirty() and utils.yes_no_dialog(not_ok_msg) \
                 or not self.presenter.dirty():
@@ -541,6 +543,7 @@ class PlantEditor(GenericModelViewPresenterEditor):
 #        # respond to responses
         more_committed = None
         if response == self.RESPONSE_NEXT:
+            self.presenter.cleanup()
             e = PlantEditor(Plant(accession=self.model.accession),
                             parent=self.parent)
             more_committed = e.start()
@@ -564,6 +567,7 @@ class PlantEditor(GenericModelViewPresenterEditor):
                   'the database before you can add plants.\n\nWould you like '\
                   'to open the Accession editor?'
             if utils.yes_no_dialog(msg):
+                self.presenter.cleanup()
                 from bauble.plugins.garden.accession import AccessionEditor
                 e = AccessionEditor()
                 return e.start()
@@ -572,6 +576,7 @@ class PlantEditor(GenericModelViewPresenterEditor):
                   'the database before you can add species.\n\nWould you '\
                   'like to open the Location editor?'
             if utils.yes_no_dialog(msg):
+                self.presenter.cleanup()
                 e = LocationEditor()
                 return e.start()
         view = PlantEditorView(parent=self.parent)
