@@ -116,7 +116,6 @@ class GardenTestCase(BaubleTestCase):
 
 class DonorTests(GardenTestCase):
 
-
     def __init__(self, *args):
         super(DonorTests, self).__init__(*args)
 
@@ -362,6 +361,12 @@ class AccessionTests(GardenTestCase):
         self.assertEquals(acc.source.id, donation2.id)
         self.assertEquals(acc.source_type, u'Donation')
 
+        # set the same source twice to make sure the source isn't
+        # deleted before setting it again
+        acc.source = donation2
+        self.session.commit()
+        self.assert_(acc.source)
+
         # delete all the donations
         # TODO: the donor should never be deleted if a donation is
         # deleted and a donation should never get deleted if a donor
