@@ -63,7 +63,8 @@ def remove_callback(family):
         msg = _('Could not delete.\n\n%s') % utils.xml_safe_utf8(e)
         utils.message_details_dialog(msg, traceback.format_exc(),
                                      type=gtk.MESSAGE_ERROR)
-    session.close()
+    finally:
+        session.close()
     return True
 
 
@@ -220,6 +221,7 @@ class FamilyEditorView(editor.GenericEditorView):
         self.dialog = self.widgets.family_dialog
         self.dialog.set_transient_for(parent)
         self.attach_completion('fam_syn_entry')#, self.syn_cell_data_func)
+        self.set_accept_buttons_sensitive(False)
         self.connect_dialog_close(self.widgets.family_dialog)
         self.restore_state()
 
@@ -487,7 +489,6 @@ class FamilyEditor(editor.GenericModelViewPresenterEditor):
                 msg = _('Error committing changes.\n\n%s') % \
                       utils.xml_safe_utf8(e.orig)
                 utils.message_details_dialog(msg, str(e), gtk.MESSAGE_ERROR)
-                self.session.rollback()
                 return False
             except Exception, e:
                 msg = _('Unknown error when committing changes. See the ' \
@@ -495,9 +496,9 @@ class FamilyEditor(editor.GenericModelViewPresenterEditor):
                       utils.xml_safe_utf8(e)
                 utils.message_details_dialog(msg, traceback.format_exc(),
                                              gtk.MESSAGE_ERROR)
-                self.session.rollback()
                 return False
-        elif self.presenter.dirty() and utils.yes_no_dialog(not_ok_msg) or not self.presenter.dirty():
+        elif self.presenter.dirty() and utils.yes_no_dialog(not_ok_msg) or \
+                not self.presenter.dirty():
             self.session.rollback()
             return True
         else:
@@ -506,6 +507,7 @@ class FamilyEditor(editor.GenericModelViewPresenterEditor):
         # respond to responses
         more_committed = None
         if response == self.RESPONSE_NEXT:
+            self.presenter.cleanup()
             e = FamilyEditor(parent=self.parent)
             more_committed = e.start()
         elif response == self.RESPONSE_OK_AND_ADD:
@@ -630,6 +632,8 @@ class GeneralFamilyExpander(InfoExpander):
 
 class SynonymsExpander(InfoExpander):
 
+    expanded_pref = 'infobox.family.synonyms.expanded'
+
     def __init__(self, widgets):
         InfoExpander.__init__(self, _("Synonyms"), widgets)
         synonyms_box = self.widgets.fam_synonyms_box
@@ -643,17 +647,16 @@ class SynonymsExpander(InfoExpander):
 
         @param row: the row to get thevalues from
         '''
-        #debug(row.synonyms)
+        syn_box = self.widgets.fam_synonyms_box
+        # remove old labels
+        syn_box.foreach(syn_box.remove)
+        # use True comparison in case the preference isn't set
+        self.set_expanded(prefs[self.expanded_pref] == True)
         if len(row.synonyms) == 0:
             self.set_sensitive(False)
-            self.set_expanded(False)
         else:
-            def on_label_clicked(label, event, syn):
-                select_in_search_results(syn)
-            syn_box = self.widgets.fam_synonyms_box
+            on_clicked = lambda l, e, syn: select_in_search_results(syn)
             for syn in row.synonyms:
-                # remove all the children
-                syn_box.foreach(syn_box.remove)
                 # create clickable label that will select the synonym
                 # in the search results
                 box = gtk.EventBox()
@@ -661,13 +664,10 @@ class SynonymsExpander(InfoExpander):
                 label.set_alignment(0, .5)
                 label.set_markup(Family.str(syn))
                 box.add(label)
-                utils.make_label_clickable(label, on_label_clicked, syn)
+                utils.make_label_clickable(label, on_clicked, syn)
                 syn_box.pack_start(box, expand=False, fill=False)
             self.show_all()
-
             self.set_sensitive(True)
-            # TODO: get expanded state from prefs
-            self.set_expanded(True)
 
 
 
