@@ -73,7 +73,8 @@ def remove_callback(genus):
         msg = _('Could not delete.\n\n%s') % utils.xml_safe_utf8(e)
         utils.message_details_dialog(msg, traceback.format_exc(),
                                      type=gtk.MESSAGE_ERROR)
-    session.close()
+    finally:
+        session.close()
     return True
 
 
@@ -248,6 +249,7 @@ class GenusEditorView(editor.GenericEditorView):
                                               parent=parent)
         self.dialog = self.widgets.genus_dialog
         self.dialog.set_transient_for(parent)
+        self.set_accept_buttons_sensitive(False)
         self.connect_dialog_close(self.dialog)
         self.attach_completion('gen_syn_entry', self.syn_cell_data_func)
         self.attach_completion('gen_family_entry')
@@ -333,8 +335,8 @@ class GenusEditorPresenter(editor.GenericEditorPresenter):
         self.assign_completions_handler('gen_family_entry',fam_get_completions,
                                         on_select=on_select)
         self.assign_simple_handler('gen_genus_entry', 'genus')
-        self.assign_simple_handler('gen_hybrid_combo', 'hybrid',
-                                   editor.UnicodeOrNoneValidator())
+        self.assign_simple_handler('gen_hybrid_combo', 'hybrid')#,
+                                   #editor.UnicodeOrNoneValidator())
         self.assign_simple_handler('gen_author_entry', 'author',
                                    editor.UnicodeOrNoneValidator())
         #self.assign_simple_handler('gen_qualifier_combo', 'qualifier')
@@ -567,7 +569,6 @@ class GenusEditor(editor.GenericModelViewPresenterEditor):
                 msg = _('Error committing changes.\n\n%s') % \
                       utils.xml_safe_utf8(e.orig)
                 utils.message_details_dialog(msg, str(e), gtk.MESSAGE_ERROR)
-                self.session.rollback()
                 return False
             except Exception, e:
                 msg = _('Unknown error when committing changes. See the '\
@@ -575,7 +576,6 @@ class GenusEditor(editor.GenericModelViewPresenterEditor):
                         utils.xml_safe_utf8(e)
                 utils.message_details_dialog(msg, traceback.format_exc(),
                                              gtk.MESSAGE_ERROR)
-                self.session.rollback()
                 return False
         elif self.presenter.dirty() \
                  and utils.yes_no_dialog(not_ok_msg) \
@@ -583,11 +583,14 @@ class GenusEditor(editor.GenericModelViewPresenterEditor):
             self.session.rollback()
             return True
         else:
+            # we get here if when asked if we're sure we want to
+            # Cancel we click No
             return False
 
         # respond to responses
         more_committed = None
         if response == self.RESPONSE_NEXT:
+            self.presenter.cleanup()
             model = Genus(family=self.model.family)
             e = GenusEditor(model=model, parent=self.parent)
             more_committed = e.start()
@@ -790,6 +793,8 @@ class GeneralGenusExpander(InfoExpander):
 
 class SynonymsExpander(InfoExpander):
 
+    expanded_pref = 'infobox.genus.synonyms.expanded'
+
     def __init__(self, widgets):
         InfoExpander.__init__(self, _("Synonyms"), widgets)
         synonyms_box = self.widgets.gen_synonyms_box
@@ -803,17 +808,16 @@ class SynonymsExpander(InfoExpander):
 
         @param row: the row to get the values from
         '''
-        #debug(row.synonyms)
+        syn_box = self.widgets.gen_synonyms_box
+        # remove old labels
+        syn_box.foreach(syn_box.remove)
+        # use True comparison in case the preference isn't set
+        self.set_expanded(prefs[self.expanded_pref] == True)
         if len(row.synonyms) == 0:
             self.set_sensitive(False)
-            self.set_expanded(False)
         else:
-            def on_label_clicked(label, event, syn):
-                select_in_search_results(syn)
-            syn_box = self.widgets.gen_synonyms_box
+            on_clicked = lambda l, e, syn: select_in_search_results(syn)
             for syn in row.synonyms:
-                # remove all the children
-                syn_box.foreach(syn_box.remove)
                 # create clickable label that will select the synonym
                 # in the search results
                 box = gtk.EventBox()
@@ -821,13 +825,10 @@ class SynonymsExpander(InfoExpander):
                 label.set_alignment(0, .5)
                 label.set_markup(Genus.str(syn, author=True))
                 box.add(label)
-                utils.make_label_clickable(label, on_label_clicked, syn)
+                utils.make_label_clickable(label, on_clicked, syn)
                 syn_box.pack_start(box, expand=False, fill=False)
             self.show_all()
-
             self.set_sensitive(True)
-            # TODO: get expanded state from prefs
-            self.set_expanded(True)
 
 
 
