@@ -60,8 +60,11 @@ class SpeciesEditorPresenter(editor.GenericEditorPresenter):
 
         # connect signals
         def gen_get_completions(text):
-            clause = or_(utils.ilike(Genus.genus, '%s%%' % unicode(text)),
-                         utils.ilike(Genus.hybrid, '%s%%' % unicode(text)))
+            if text.startswith('x'):
+                clause = or_(utils.ilike(Genus.genus, '%s%%' % unicode(text)),
+                           utils.ilike(Genus.hybrid, '%s%%' % unicode(text[0])))
+            else:
+                clause = utils.ilike(Genus.genus, '%s%%' % unicode(text))
             return self.session.query(Genus).filter(clause)
 
         #def set_in_model(self, field, value):
@@ -75,18 +78,18 @@ class SpeciesEditorPresenter(editor.GenericEditorPresenter):
 
         self.assign_simple_handler('sp_species_entry', 'sp',
                                    editor.UnicodeOrNoneValidator())
-        self.assign_simple_handler('sp_infra_rank_combo', 'infrasp_rank',
-                                   editor.UnicodeOrNoneValidator())
-        self.assign_simple_handler('sp_hybrid_combo', 'sp_hybrid',
-                                   editor.UnicodeOrNoneValidator())
+        self.assign_simple_handler('sp_infra_rank_combo', 'infrasp_rank')#,
+                                   #editor.UnicodeOrNoneValidator())
+        self.assign_simple_handler('sp_hybrid_combo', 'sp_hybrid')#,
+                                   #editor.UnicodeOrNoneValidator())
         self.assign_simple_handler('sp_infra_entry', 'infrasp',
                                    editor.UnicodeOrNoneValidator())
         self.assign_simple_handler('sp_cvgroup_entry', 'cv_group',
                                    editor.UnicodeOrNoneValidator())
         self.assign_simple_handler('sp_infra_author_entry', 'infrasp_author',
                                    editor.UnicodeOrNoneValidator())
-        self.assign_simple_handler('sp_spqual_combo', 'sp_qual',
-                                   editor.UnicodeOrNoneValidator())
+        self.assign_simple_handler('sp_spqual_combo', 'sp_qual')#,
+                                   #editor.UnicodeOrNoneValidator())
         self.assign_simple_handler('sp_author_entry', 'sp_author',
                                    editor.UnicodeOrNoneValidator())
         self.assign_simple_handler('sp_notes_textview', 'notes',
@@ -429,6 +432,9 @@ class VernacularNamePresenter(editor.GenericEditorPresenter):
         self.session = session
         self.__dirty = False
         self.init_treeview(species.vernacular_names)
+        # clear the name and language entries
+        self.view.widgets.vern_name_entry.props.text = ''
+        self.view.widgets.vern_lang_entry.props.text = ''
         self.view.connect('sp_vern_add_button', 'clicked',
                           self.on_add_button_clicked)
         self.view.connect('sp_vern_remove_button', 'clicked',
@@ -530,7 +536,7 @@ class VernacularNamePresenter(editor.GenericEditorPresenter):
         tree_model.remove(tree_model.get_iter(path))
         self.model.vernacular_names.remove(value)
         if self.model.default_vernacular_name is not None \
-               and value.model == self.model.default_vernacular_name:
+               and value == self.model.default_vernacular_name:
             # if there is only one value in the tree then set it as the
             # default vernacular name
             first = tree_model.get_iter_first()
@@ -843,6 +849,7 @@ class SpeciesEditorView(editor.GenericEditorView):
         super(SpeciesEditorView, self).__init__(glade_path, parent=parent)
         self.dialog = self.widgets.species_dialog
         self.dialog.set_transient_for(parent)
+        self.set_accept_buttons_sensitive(False)
         self.attach_completion('sp_genus_entry',
                                self.genus_completion_cell_data_func,
                                match_func=self.genus_match_func)
@@ -971,7 +978,6 @@ class SpeciesEditor(editor.GenericModelViewPresenterEditor):
                 msg = _('Error committing changes.\n\n%s') % \
                       utils.xml_safe_utf8(e.orig)
                 utils.message_details_dialog(msg, str(e), gtk.MESSAGE_ERROR)
-                self.session.rollback()
                 return False
             except Exception, e:
                 msg = _('Unknown error when committing changes. See the '\
@@ -981,7 +987,6 @@ class SpeciesEditor(editor.GenericModelViewPresenterEditor):
                 #warning(traceback.format_exc())
                 utils.message_details_dialog(msg, traceback.format_exc(),
                                              gtk.MESSAGE_ERROR)
-                self.session.rollback()
                 return False
         elif self.presenter.dirty() and utils.yes_no_dialog(not_ok_msg) \
                  or not self.presenter.dirty():
@@ -992,6 +997,7 @@ class SpeciesEditor(editor.GenericModelViewPresenterEditor):
 
         more_committed = None
         if response == self.RESPONSE_NEXT:
+            self.presenter.cleanup()
             e = SpeciesEditor(Species(genus=self.model.genus), self.parent)
             more_committed = e.start()
         elif response == self.RESPONSE_OK_AND_ADD:
