@@ -374,8 +374,11 @@ class GenusTests(PlantTestCase):
         Interactively test the PlantEditor
         """
         #loc = self.create(Genus, site=u'some site')
-        fam = Genus(genus='some genus')
-        editor = GenusEditor(model=fam)
+        fam = self.session.query(Family).get(1)
+        gen = Genus(genus='some genus', family=fam)
+        gen2 = Genus(genus='genus2', family=fam)
+        gen.synonyms.append(gen2)
+        editor = GenusEditor(model=gen)
         editor.start()
         del editor
         assert utils.gc_objects_by_type('GenusEditor') == [], \
