@@ -7,7 +7,7 @@ from bauble.prefs import prefs
 import bauble.pluginmgr as pluginmgr
 
 uri = 'sqlite:///:memory:'
-uri = 'postgres://postgres:4postgres*@localhost/test'
+#uri = 'postgres://postgres:4postgres*@localhost/test'
 
 def init_bauble(uri):
     try:
