@@ -105,7 +105,7 @@ class GladeWidgets(dict):
         '''
         w = self.glade_xml.get_widget(name)
         if not w:
-            raise KeyError(_('%s not in glade file' % w))
+            raise KeyError(_('%s not in glade file' % name))
         return w
 
 
@@ -714,8 +714,6 @@ def enum_values_str(col):
 
 
 class MessageBox(gtk.EventBox):
-
-
     # TODO: instead of passing colors to show we should just pass a
     # state variable so that the colors will be consistent across the
     # app...error=red, notifcation=blue, info=white
