@@ -56,6 +56,9 @@ class InfoExpander(gtk.Expander):
     to extend this you just have to implement the update() method
     """
 
+    # preference for storing the expanded state
+    expanded_pref = None
+
     def __init__(self, label, widgets=None):
         """
         :param label: the name of this info expander, this is displayed on the
@@ -69,6 +72,13 @@ class InfoExpander(gtk.Expander):
         self.add(self.vbox)
         self.set_expanded(True)
         self.widgets = widgets
+        self.connect("notify::expanded", self.on_expanded)
+
+
+    def on_expanded(self, expander, *args):
+        if self.expanded_pref:
+            prefs[self.expanded_pref] = expander.get_expanded()
+            prefs.save()
 
 
     def set_widget_value(self, widget_name, value, markup=True, default=None):
@@ -767,7 +777,6 @@ class SearchView(pluginmgr.View):
         except Exception, e:
             debug('SearchView.update_infobox: %s' % e)
             debug(traceback.format_exc())
-            debug(values)
             self.set_infobox_from_row(None)
 
 
@@ -1047,9 +1056,19 @@ class SearchView(pluginmgr.View):
         return model
 
 
-    def cell_data_func(self, coll, cell, model, iter):
+    def cell_data_func(self, col, cell, model, iter):
         value = model[iter][0]
         #debug('%s(%s)' % (value, type(value)))
+
+        path = model.get_path(iter)
+        tree_rect = self.results_view.get_visible_rect()
+        cell_rect = self.results_view.get_cell_area(path, col)
+        if cell_rect.y > tree_rect.height:
+            # only update the cells if they're visible...this
+            # drastically speeds up populating the view with large
+            # datasets
+            return
+
         if isinstance(value, basestring):
             cell.set_property('markup', value)
         else:
@@ -1070,7 +1089,7 @@ class SearchView(pluginmgr.View):
                                    _substr_tmpl % utils.utf8(substr)))
 
             except (saexc.InvalidRequestError, TypeError), e:
-                warning('bauble.view.SearchView.cell_data_func(): \n%s' % e)
+                #warning('bauble.view.SearchView.cell_data_func(): \n%s' % e)
                 def remove():
                     model = self.results_view.get_model()
                     self.results_view.set_model(None) # detach model
